@@ -246,6 +246,12 @@ os_hierarchy.each do |os|
 
     require_relative '../../resolvers/amzn/os_release_rpm'
 
+  when 'archlinux'
+    require_relative '../../facts/archlinux/os/release'
+
+  when 'azurelinux'
+    require_relative '../../facts/azurelinux/os/release'
+
   when 'bsd'
     require_relative '../../facts/bsd/kernelmajversion'
     require_relative '../../facts/bsd/kernelversion'
@@ -372,6 +378,7 @@ os_hierarchy.each do |os|
   when 'linux'
     require_relative '../../util/linux/dhcp'
     require_relative '../../util/linux/if_inet6'
+    require_relative '../../util/linux/proc'
     require_relative '../../util/linux/routing_table'
     require_relative '../../util/linux/socket_parser'
 
@@ -482,6 +489,7 @@ os_hierarchy.each do |os|
     require_relative '../../facts/linux/processor'
     require_relative '../../facts/linux/processors/cores'
     require_relative '../../facts/linux/processors/count'
+    require_relative '../../facts/linux/processors/extensions'
     require_relative '../../facts/linux/processors/isa'
     require_relative '../../facts/linux/processors/models'
     require_relative '../../facts/linux/processors/physicalcount'
@@ -651,63 +659,63 @@ os_hierarchy.each do |os|
     require_relative '../../facts/ol/os/distro/id'
 
   when 'openbsd'
-    require_relative '../../facts/openbsd/augeas/version.rb'
-    require_relative '../../facts/openbsd/ec2_metadata.rb'
-    require_relative '../../facts/openbsd/ec2_userdata.rb'
-    require_relative '../../facts/openbsd/facterversion.rb'
-    require_relative '../../facts/openbsd/is_virtual.rb'
-    require_relative '../../facts/openbsd/kernel.rb'
-    require_relative '../../facts/openbsd/kernelrelease.rb'
-    require_relative '../../facts/openbsd/mountpoints.rb'
-    require_relative '../../facts/openbsd/path.rb'
-    require_relative '../../facts/openbsd/ssh.rb'
-    require_relative '../../facts/openbsd/sshalgorithmkey.rb'
-    require_relative '../../facts/openbsd/sshfp_algorithm.rb'
-    require_relative '../../facts/openbsd/timezone.rb'
-    require_relative '../../facts/openbsd/virtual.rb'
-    require_relative '../../facts/openbsd/dmi/bios/vendor.rb'
-    require_relative '../../facts/openbsd/dmi/bios/version.rb'
-    require_relative '../../facts/openbsd/dmi/manufacturer.rb'
-    require_relative '../../facts/openbsd/dmi/product/name.rb'
-    require_relative '../../facts/openbsd/dmi/product/serial_number.rb'
-    require_relative '../../facts/openbsd/dmi/product/uuid.rb'
-    require_relative '../../facts/openbsd/identity/group.rb'
-    require_relative '../../facts/openbsd/identity/gid.rb'
-    require_relative '../../facts/openbsd/identity/privileged.rb'
-    require_relative '../../facts/openbsd/identity/uid.rb'
-    require_relative '../../facts/openbsd/identity/user.rb'
-    require_relative '../../facts/openbsd/networking/dhcp.rb'
-    require_relative '../../facts/openbsd/networking/domain.rb'
-    require_relative '../../facts/openbsd/networking/fqdn.rb'
-    require_relative '../../facts/openbsd/networking/hostname.rb'
-    require_relative '../../facts/openbsd/networking/interfaces.rb'
-    require_relative '../../facts/openbsd/networking/ip.rb'
-    require_relative '../../facts/openbsd/networking/ip6.rb'
-    require_relative '../../facts/openbsd/networking/mac.rb'
-    require_relative '../../facts/openbsd/networking/mtu.rb'
-    require_relative '../../facts/openbsd/networking/netmask.rb'
-    require_relative '../../facts/openbsd/networking/netmask6.rb'
-    require_relative '../../facts/openbsd/networking/network.rb'
-    require_relative '../../facts/openbsd/networking/network6.rb'
-    require_relative '../../facts/openbsd/networking/primary.rb'
-    require_relative '../../facts/openbsd/networking/scope6.rb'
-    require_relative '../../facts/openbsd/os/architecture.rb'
-    require_relative '../../facts/openbsd/os/hardware.rb'
-    require_relative '../../facts/openbsd/os/name.rb'
-    require_relative '../../facts/openbsd/os/release.rb'
-    require_relative '../../facts/openbsd/processors/isa.rb'
-    require_relative '../../facts/openbsd/ruby/platform.rb'
-    require_relative '../../facts/openbsd/ruby/sitedir.rb'
-    require_relative '../../facts/openbsd/ruby/version.rb'
-    require_relative '../../facts/openbsd/system_uptime/days.rb'
-    require_relative '../../facts/openbsd/system_uptime/hours.rb'
-    require_relative '../../facts/openbsd/system_uptime/seconds.rb'
-    require_relative '../../facts/openbsd/system_uptime/uptime.rb'
+    require_relative '../../facts/openbsd/augeas/version'
+    require_relative '../../facts/openbsd/ec2_metadata'
+    require_relative '../../facts/openbsd/ec2_userdata'
+    require_relative '../../facts/openbsd/facterversion'
+    require_relative '../../facts/openbsd/is_virtual'
+    require_relative '../../facts/openbsd/kernel'
+    require_relative '../../facts/openbsd/kernelrelease'
+    require_relative '../../facts/openbsd/mountpoints'
+    require_relative '../../facts/openbsd/path'
+    require_relative '../../facts/openbsd/ssh'
+    require_relative '../../facts/openbsd/sshalgorithmkey'
+    require_relative '../../facts/openbsd/sshfp_algorithm'
+    require_relative '../../facts/openbsd/timezone'
+    require_relative '../../facts/openbsd/virtual'
+    require_relative '../../facts/openbsd/dmi/bios/vendor'
+    require_relative '../../facts/openbsd/dmi/bios/version'
+    require_relative '../../facts/openbsd/dmi/manufacturer'
+    require_relative '../../facts/openbsd/dmi/product/name'
+    require_relative '../../facts/openbsd/dmi/product/serial_number'
+    require_relative '../../facts/openbsd/dmi/product/uuid'
+    require_relative '../../facts/openbsd/identity/group'
+    require_relative '../../facts/openbsd/identity/gid'
+    require_relative '../../facts/openbsd/identity/privileged'
+    require_relative '../../facts/openbsd/identity/uid'
+    require_relative '../../facts/openbsd/identity/user'
+    require_relative '../../facts/openbsd/networking/dhcp'
+    require_relative '../../facts/openbsd/networking/domain'
+    require_relative '../../facts/openbsd/networking/fqdn'
+    require_relative '../../facts/openbsd/networking/hostname'
+    require_relative '../../facts/openbsd/networking/interfaces'
+    require_relative '../../facts/openbsd/networking/ip'
+    require_relative '../../facts/openbsd/networking/ip6'
+    require_relative '../../facts/openbsd/networking/mac'
+    require_relative '../../facts/openbsd/networking/mtu'
+    require_relative '../../facts/openbsd/networking/netmask'
+    require_relative '../../facts/openbsd/networking/netmask6'
+    require_relative '../../facts/openbsd/networking/network'
+    require_relative '../../facts/openbsd/networking/network6'
+    require_relative '../../facts/openbsd/networking/primary'
+    require_relative '../../facts/openbsd/networking/scope6'
+    require_relative '../../facts/openbsd/os/architecture'
+    require_relative '../../facts/openbsd/os/hardware'
+    require_relative '../../facts/openbsd/os/name'
+    require_relative '../../facts/openbsd/os/release'
+    require_relative '../../facts/openbsd/processors/isa'
+    require_relative '../../facts/openbsd/ruby/platform'
+    require_relative '../../facts/openbsd/ruby/sitedir'
+    require_relative '../../facts/openbsd/ruby/version'
+    require_relative '../../facts/openbsd/system_uptime/days'
+    require_relative '../../facts/openbsd/system_uptime/hours'
+    require_relative '../../facts/openbsd/system_uptime/seconds'
+    require_relative '../../facts/openbsd/system_uptime/uptime'
 
-    require_relative '../../resolvers/openbsd/dhcp.rb'
-    require_relative '../../resolvers/openbsd/dmi.rb'
-    require_relative '../../resolvers/openbsd/mountpoints.rb'
-    require_relative '../../resolvers/openbsd/virtual.rb'
+    require_relative '../../resolvers/openbsd/dhcp'
+    require_relative '../../resolvers/openbsd/dmi'
+    require_relative '../../resolvers/openbsd/mountpoints'
+    require_relative '../../resolvers/openbsd/virtual'
 
   when 'openwrt'
     require_relative '../../facts/openwrt/os/release'
