@@ -3,10 +3,10 @@
 module Facter
   module Utils
     # Sort nested hash.
-    def self.sort_hash_by_key(hash, recursive = true, &block)
+    def self.sort_hash_by_key(hash, recursive: true, &block)
       hash.keys.sort(&block).each_with_object(hash.class.new) do |key, seed|
         seed[key] = hash[key]
-        seed[key] = sort_hash_by_key(seed[key], true, &block) if recursive && seed[key].is_a?(Hash)
+        seed[key] = sort_hash_by_key(seed[key], recursive: true, &block) if recursive && seed[key].is_a?(Hash)
 
         seed
       end
@@ -14,7 +14,7 @@ module Facter
 
     def self.split_user_query(user_query)
       queries = user_query.split('.')
-      queries.map! { |query| query =~ /^[0-9]+$/ ? query.to_i : query }
+      queries.map! { |query| /^[0-9]+$/.match?(query) ? query.to_i : query }
     end
 
     def self.deep_stringify_keys(object)
